Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(109)

Unified Diff: ui/aura/mus/mus_types.h

Issue 2839743002: Wires up WindowTreeClient::SetDisplayRoot() (Closed)
Patch Set: add .cc Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ui/aura/mus/mus_types.h
diff --git a/ui/aura/mus/mus_types.h b/ui/aura/mus/mus_types.h
index 642e00ab7be419fd49389b611efd94983063e6b7..8c4f305f3b22070d55e3cd2aa8b70ed9a7522b1a 100644
--- a/ui/aura/mus/mus_types.h
+++ b/ui/aura/mus/mus_types.h
@@ -40,8 +40,13 @@ enum class WindowMusType {
// The window is a top level window in the window manager.
TOP_LEVEL_IN_WM,
- // The window is a display root for the window manager.
- DISPLAY,
+ // The window is a display root for the window manager and was automatically
+ // created by mus.
+ DISPLAY_AUTOMATICALLY_CREATED,
+
+ // The window is a display root for the window manager and was manually
+ // created.
+ DISPLAY_MANUALLY_CREATED,
// The window was created locally.
LOCAL,
« no previous file with comments | « no previous file | ui/aura/mus/window_manager_delegate.h » ('j') | ui/aura/mus/window_tree_host_mus_init_params.h » ('J')

Powered by Google App Engine
This is Rietveld 408576698